@@ -1,21 +1,23 @@
 /*
- * Copyright (c) Members of the EGEE Collaboration. 2010.
- * See http://www.eu-egee.org/partners/ for details on the copyright holders.
+ * Copyright (c) CERN 2013-2015
+ *
+ * Copyright (c) Members of the EMI Collaboration. 2010-2013
+ *  See  http://www.eu-emi.eu/partners for details on the copyright
+ *  holders.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *    http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- *
- * Authors: Todor Manev  IT-GT CERN
  */
+
 #include <errno.h>
 #include <regex.h>
 #include <assert.h>
@@ -449,7 +451,11 @@ int srmv2_mkdir(struct srm_context *context,struct srm_mkdir_input *input)
 			errno = srm_soap_call_err(context, srmfunc);
             goto CLEANUP_AND_RETURN;
 		}
-
+	        if (rep.srmMkdirResponse == NULL) {
+			srm_errmsg (context, "[SRM][srmv2_makedirp][EINVAL] %s: Invalid response from the server", input->dir_name);
+			errno = EINVAL;
+	     		goto CLEANUP_AND_RETURN;
+                } 
 		repstatp = rep.srmMkdirResponse->returnStatus;
 		sav_errno = statuscode2errno (repstatp->statusCode);
 
